/*
 * The olsr.org Optimized Link-State Routing daemon (olsrd)
 * Copyright (c) 2004, Thomas Lopatic (thomas@lopatic.de)
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 *
 * * Redistributions of source code must retain the above copyright 
 *   notice, this list of conditions and the following disclaimer.
 * * Redistributions in binary form must reproduce the above copyright 
 *   notice, this list of conditions and the following disclaimer in 
 *   the documentation and/or other materials provided with the 
 *   distribution.
 * * Neither the name of olsr.org, olsrd nor the names of its 
 *   contributors may be used to endorse or promote products derived 
 *   from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * Visit http://www.olsr.org for more information.
 *
 * If you find this software useful feel free to make a donation
 * to the project. For more information see the website or contact
 * the copyright holders.
 *
 */

#ifdef _WIN32

#include "stdafx.h"
#include "NodeEntry.h"

class NodeEntry &NodeEntry::operator=(class NodeEntry &Src)
{
	Addr = Src.Addr;
	Timeout = Src.Timeout;

	MprList.RemoveAll();
	MprList.AddHead(&Src.MprList);

	HnaList.RemoveAll();
	HnaList.AddHead(&Src.HnaList);

	MidList.RemoveAll();
	MidList.AddHead(&Src.MidList);

	return *this;
}

BOOL NodeEntry::operator==(const class NodeEntry &Comp) const
{
	return Addr == Comp.Addr;
}

void NodeEntry::AddMpr(unsigned int MprAddr, unsigned __int64 Timeout)
{
	class MprEntry NewEntry;
	POSITION Pos;

	NewEntry.Addr = MprAddr;

	Pos = MprList.Find(NewEntry);

	if (Pos != NULL)
	{
		class MprEntry &OldEntry = MprList.GetAt(Pos);
		OldEntry.Timeout = Timeout;
	}

	else
	{
		NewEntry.Timeout = Timeout;
		MprList.AddTail(NewEntry);
	}
}

void NodeEntry::AddMid(unsigned int IntAddr, unsigned __int64 Timeout)
{
	class MidEntry NewEntry;
	POSITION Pos;

	NewEntry.Addr = IntAddr;

	Pos = MidList.Find(NewEntry);

	if (Pos != NULL)
	{
		class MidEntry &OldEntry = MidList.GetAt(Pos);
		OldEntry.Timeout = Timeout;
	}

	else
	{
		NewEntry.Timeout = Timeout;
		MidList.AddTail(NewEntry);
	}
}

void NodeEntry::AddHna(unsigned int NetAddr, unsigned int NetMask,
					   unsigned __int64 Timeout)
{
	class HnaEntry NewEntry;
	POSITION Pos;

	NewEntry.Addr = NetAddr;
	NewEntry.Mask = NetMask;

	Pos = HnaList.Find(NewEntry);

	if (Pos != NULL)
	{
		class HnaEntry &OldEntry = HnaList.GetAt(Pos);
		OldEntry.Timeout = Timeout;
	}

	else
	{
		NewEntry.Timeout = Timeout;
		HnaList.AddTail(NewEntry);
	}
}

#endif /* _WIN32 */
